% TODO: 
% * tabular, array environment
% * font selection overflows
% * a3split
% * two line titles
% * frames as environment
% * documentation
% * \newtheorem*


% 0. Organisatorical items: 
% Options, links to other packages, etc.
\NeedsTeXFormat{LaTeX2e}[1995/12/01]
\ProvidesClass{poster}

\newcount\@noColumns

\newif\if@colormode
\DeclareOption{color}{\@colormodetrue}
\DeclareOption{bw}{\@colormodefalse}

% set to true to get shifted copies of size a4
\newif\if@split
\@splitfalse

% is set to true if a splitting yields landscape a4 papers
\newif\if@across
\@acrossfalse

\DeclareOption{split}{\@splittrue}

\DeclareOption{draft}{\@colormodefalse\setlength\overfullrule{5pt}}
\DeclareOption{final}{\setlength\overfullrule{0pt}}

\DeclareOption{a0paper}{%
  \@acrossfalse
  \setlength\paperwidth{840mm}%
  \setlength\paperheight{1188mm}%
  \@noColumns=4}
\DeclareOption{a1paper}{%
  \@acrosstrue
  \setlength\paperwidth{594mm}%
  \setlength\paperheight{840mm}%
  \@noColumns=4}
\DeclareOption{a2paper}{%
  \@acrossfalse
  \setlength\paperwidth{420mm}%
  \setlength\paperheight{594mm}%
  \@noColumns=3}
\DeclareOption{a3paper}{%
  \@acrosstrue
  \setlength\paperwidth{297mm}%
  \setlength\paperheight{420mm}%
  \@noColumns=3}
\DeclareOption{a4paper}{%
  \@acrossfalse
  \setlength\paperwidth{210mm}%
  \setlength\paperheight{297mm}%
  \@noColumns=2}

\DeclareOption{landscape}{%
  \if@across
    \@acrossfalse
  \else
    \@acrosstrue
  \fi
  \@tempdima\paperwidth
  \paperwidth\paperheight
  \paperheight\@tempdima
  \advance\@noColumns by 1\relax
}

\DeclareOption{cols=2}{\@noColumns=2}
\DeclareOption{cols=3}{\@noColumns=3}
\DeclareOption{cols=4}{\@noColumns=4}
\DeclareOption{cols=5}{\@noColumns=5}
\DeclareOption{cols=6}{\@noColumns=6}

\DeclareOption{5pt}{\def\@@normalsize{0}}
\DeclareOption{6pt}{\def\@@normalsize{1}}
\DeclareOption{7pt}{\def\@@normalsize{2}}
\DeclareOption{8pt}{\def\@@normalsize{3}}
\DeclareOption{9pt}{\def\@@normalsize{4}}
\DeclareOption{10pt}{\def\@@normalsize{5}}
\DeclareOption{12pt}{\def\@@normalsize{6}}
\DeclareOption{14pt}{\def\@@normalsize{7}}
\DeclareOption{16pt}{\def\@@normalsize{8}}
\DeclareOption{18pt}{\def\@@normalsize{9}}
\DeclareOption{20pt}{\def\@@normalsize{10}}
\DeclareOption{24pt}{\def\@@normalsize{11}}

\ExecuteOptions{final,color,a3paper}
\ProcessOptions

\RequirePackage{epsfig}
\RequirePackage{color}
% The ams stuff is not really needed, but is causes trouble if it is
% loaded afterwards, so we load it beforehand...
\RequirePackage{amssymb} 
\RequirePackage{amsmath}

\definecolor{grey}{rgb}{.85,.85,.85}

\definecolor{darkred}{rgb}{.65,0,0}
\definecolor{lightred}{rgb}{1,.9,.9}

\definecolor{darkgreen}{rgb}{0,.6,0}
\definecolor{lightgreen}{rgb}{.85,1,.85}

\definecolor{darkblue}{rgb}{0,0,.82}
\definecolor{lightblue}{rgb}{.85,.9,1}

\definecolor{darkyellow}{rgb}{.7,.7,0}
\definecolor{lightyellow}{rgb}{1,1,.9}

\definecolor{darkmagenta}{rgb}{.7,0,.7}
\definecolor{lightmagenta}{rgb}{1,.9,1}

\definecolor{darkcyan}{rgb}{0,.7,.7}
\definecolor{lightcyan}{rgb}{.9,1,1}

\definecolor{darkwhite}{rgb}{0,0,0}
\definecolor{lightwhite}{rgb}{1,1,1}

\newcount\@tempcntc
\newcount\@tempcntd
\newcount\@tempcnte

\newdimen\@tempdimd
\newdimen\@tempdime

\newtoks\@temptoksa

% I. shape the page
\input poster-paper

% II. select and declare fonts
\input poster-fonts

% III. define layout elements like section headings etc.
\input poster-layout

% IV. Multicolumn Environment
\input poster-frames

% V. Misc
\def\title#1{\gdef\the@title{#1}}
\def\author#1{\gdef\the@author{#1}}
\let\the@title\undefined
\let\the@author\undefined
\def\thepage{1} % for convenience

\def\today{\ifcase\month\or
  January\or February\or March\or April\or May\or June\or
  July\or August\or September\or October\or November\or December\fi
  \space\number\day, \number\year}

\def\now{%
  \@tempcnta=\time
  \divide\@tempcnta by60
  \the\@tempcnta:%
  \multiply\@tempcnta by-60
  \advance\@tempcnta by\time
  \ifnum\@tempcnta<10 0\fi
  \the\@tempcnta\relax
}

%% End of file `poster.cls'.

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%EMACS Local Variables:
%EMACS mode: iso-latex-minor
%EMACS End:
